/*
 * Copyright 2012-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.actuate.metrics;

import java.lang.reflect.AnnotatedElement;
import java.util.Arrays;
import java.util.stream.Stream;

import io.micrometer.core.annotation.Timed;
import io.micrometer.core.annotation.TimedSet;

import org.springframework.core.annotation.AnnotationUtils;

/**
 * A utility class for finding {@link Timed} annotations.
 *
 * @author Jon Schneider
 * @since 2.0.0
 */
public final class TimedUtils {
	private TimedUtils() {
	}

	public static Stream<Timed> findTimedAnnotations(AnnotatedElement element) {
		Timed t = AnnotationUtils.findAnnotation(element, Timed.class);
		if (t != null)
			return Stream.of(t);

		TimedSet ts = AnnotationUtils.findAnnotation(element, TimedSet.class);
		if (ts != null) {
			return Arrays.stream(ts.value());
		}

		return Stream.empty();
	}
}
